Method: Fog::OpenStack::Compute::SecurityGroup#rules=

Defined in:
lib/fog/openstack/compute/models/security_group.rb

#rules=(new_rules) ⇒ Object

no one should be calling this because it doesn’t do anything useful but we deprecated the rules attribute and need to maintain the API



25
26
27
28
# File 'lib/fog/openstack/compute/models/security_group.rb', line 25

def rules=(new_rules)
  Fog::Logger.deprecation('#rules= is deprecated. Use the Fog::OpenStack::Compute::SecurityGroupRules collection to create new rules.')
  attributes[:security_group_rules] = new_rules
end