Method: Fog::OpenStack::Storage::File#delete_after

Defined in:
lib/fog/openstack/storage/models/file.rb

#delete_afterInteger

A number of seconds representing how long from now this object will be automatically deleted.

Returns:

  • (Integer)

    the number of seconds until this object will be automatically deleted

See Also:



28
# File 'lib/fog/openstack/storage/models/file.rb', line 28

attribute :delete_after, :aliases => ['X-Delete-After']