Method: Fog::OpenStack::Storage::File#delete_at

Defined in:
lib/fog/openstack/storage/models/file.rb

#delete_atInteger

A Unix Epoch Timestamp, in integer form, representing the time when this object will be automatically deleted.

Returns:

  • (Integer)

    the unix epoch timestamp of when this object will be automatically deleted

See Also:



22
# File 'lib/fog/openstack/storage/models/file.rb', line 22

attribute :delete_at, :aliases => ['X-Delete-At']